@@ -1,26 +1,28 @@
-"""python-mbedtls is a this wrapper to ARM's mbed TLS library."""
+# SPDX-License-Identifier: MIT
+# Copyright (c) 2015, Elaborated Networks GmbH
+# Copyright (c) 2018, Mathias Laurin
 
-__author__ = "Mathias Laurin"
-__copyright__ = "Copyright 2015, Elaborated Networks GmbH"
-__license__ = "MIT License"
+"""python-mbedtls is a this wrapper to ARM's mbed TLS library."""
 
 
 import mbedtls.cipher as cipher
 import mbedtls.exceptions as exceptions
-import mbedtls.hash as hash
-import mbedtls.hmac as hmac
+import mbedtls.hashlib as hashlib
 import mbedtls.hkdf as hkdf
+import mbedtls.hmac as hmac
 import mbedtls.pk as pk
 import mbedtls.secrets as secrets
 import mbedtls.tls as tls
 import mbedtls.version as version
 import mbedtls.x509 as x509
 
+hash = hashlib  # pylint: disable=redefined-builtin
 
 __all__ = (
     "cipher",
     "exceptions",
     "hash",
+    "hashlib",
     "hkdf",
     "hmac",
     "pk",
