@@ -3,21 +3,21 @@ import multiprocessing as mp
 import socket
 import sys
 
+import pytest
+
+from mbedtls import hashlib
+from mbedtls.exceptions import TLSError
+from mbedtls.pk import RSA
+from mbedtls.tls import *
+from mbedtls.tls import _DTLSCookie as DTLSCookie
+from mbedtls.x509 import CRT, CSR, BasicConstraints
+
 try:
     from contextlib import suppress
 except ImportError:
     # Python 2.7
     from contextlib2 import suppress
 
-import pytest
-
-import mbedtls.hash as hashlib
-from mbedtls.exceptions import TLSError
-from mbedtls.pk import RSA
-from mbedtls.x509 import BasicConstraints, CRT, CSR
-from mbedtls.tls import _DTLSCookie as DTLSCookie
-from mbedtls.tls import *
-
 
 try:
     FileNotFoundError
@@ -632,18 +632,19 @@ class TestTLS_PSKAuthenticationFailure(_TLSCommunicationBase):
 
 
 class TestDTLS_PSKAuthenticationFailure(_DTLSCommunicationBase):
-    @pytest.fixture(scope="class")
-    def ciphers(self):
-        return (
+    @pytest.fixture(
+        scope="class",
+        params=[
             "TLS-ECDHE-PSK-WITH-AES-256-CBC-SHA",
             "TLS-ECDHE-PSK-WITH-AES-128-CBC-SHA",
-            "TLS-DHE-PSK-WITH-AES-256-CBC-SHA",
-            "TLS-DHE-PSK-WITH-AES-128-CBC-SHA",
             "TLS-RSA-PSK-WITH-AES-256-CBC-SHA",
             "TLS-RSA-PSK-WITH-AES-128-CBC-SHA",
             "TLS-PSK-WITH-AES-256-CBC-SHA",
             "TLS-PSK-WITH-AES-128-CBC-SHA",
-        )
+        ],
+    )
+    def ciphers(self, request):
+        return (request.param,)
 
     @pytest.fixture(
         scope="class",
